/** Manage the printer master table.
 * @author John Green, January 1997
 * @param appSession Handle to the application session persistent procedure.
 * @param defaultPrinter The default printer for this manager.
 * @param numActivePrinters Output the number of printers
 *        where disabled is set to false.
 */

DEF INPUT PARAM appSession AS HANDLE.
DEF INPUT PARAM defaultPrinter AS CLASS Print.Printer.
DEF OUTPUT PARAM numActivePrinters AS INT.

RETURN.


/** Find a printer ID by printer name.
 * @param name The printer name or enough of the name to find it uniquely.
 * @return The printer ID  if found uniquely, otherwise zero.
 */
FUNCTION findByName RETURNS INT64 (name AS CHAR) FORWARD.


/** Find an available printer appropriate for a document.
 * @param printDocument The PrintDocument which the printer must be capable of printing.
 * @return An available Printer, null if none available.
 */
FUNCTION findAvailablePrinter RETURNS CLASS Print.Printer (document AS Print.PrintDocument):
  RETURN ?.
END FUNCTION.


/* This won't get documented - it's PRIVATE. */
FUNCTION doNotDocument RETURNS CHAR PRIVATE ():
END FUNCTION.


/** Disable a printer.
 * A disabled printer cannot have jobs submitted to it.
 * @param note The user's message attached to the printer, to tell
 *        other users why the printer has been disabled.
 * @param wasDisabled Was the printer already disabled?
 */
PROCEDURE disablePrinter:
  DEF INPUT PARAM note AS CHAR.
  DEF OUTPUT PARAM wasDisabled AS LOGICAL.
END.


/** Submit a PrintDocument to a Printer. */
PROCEDURE submit:
  DEF INPUT PARAM printer AS CLASS Print.Printer.
  DEF INPUT PARAM document AS CLASS Print.PrintDocument.
END PROCEDURE.


/* This won't get documented - the FORWARD will instead.
 * Note that this doesn't even have to declare params.
 */
FUNCTION findByName INT64:
  def var test as char.
  test = name.
  return 0.
END FUNCTION.
 