USING Progress.Lang.*.
USING Print.PrintDocument.

/** Sales order document.
 * Superclass for any kind of sales order, whether inside
 * or outside sales. Not used for POS.
 * @author John Green, August 2009
 */
CLASS Sales.SalesOrder IMPLEMENTS PrintDocument:

  /** A sales order may not be constructed without a CustomerID.
   * @param customerID The customerID may not be null or invalid.
   * A null or invalid customerID will result in a thrown exception.
   */
  CONSTRUCTOR SalesOrder(customerID AS INT64):
    THIS-OBJECT:CustomerID = customerID.
  END CONSTRUCTOR.

  DEF PUBLIC PROPERTY CustomerID AS INT64 NO-UNDO GET. PRIVATE SET.
  
  /** Assignment will notify the account manager of the new PO number. */
  DEF PUBLIC PROPERTY PONum AS CHAR
    GET.
    SET (newPONum AS CHAR):
    END SET.
  
  /** Due date is when the order must be <b>delivered</b> (not just shipped). */
  DEF PUBLIC VAR dueDate AS DATE.
 



  /** Print the sales order.
   * Calls the UI for print submission, and submits
   * the sales order to the printer selected by the user.
   * @return The print job ID, or zero if canceled.
   * @Implements PrintDocument (This is an example of an arbitrary tag in AutoDox2.)
   */
  METHOD PUBLIC INT64 print():
    RETURN 0.
  END METHOD.
  
  
  /** Send to a specific printer.
   * @deprecated Use print() instead.
   */
  METHOD PUBLIC VOID print(printerID AS INT64):
  END METHOD.
  

  /** Preview the sales order. */
  METHOD PUBLIC VOID printPreview():
  END METHOD.


END CLASS.